==> skill-core-0.0.8-sources.jar: com/ptteng/common/skill/service/TeacherService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Teacher;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface TeacherService extends BaseDaoService {

	



   		   
		
		public Long insert(Teacher teacher)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Teacher> insertList(List<Teacher> teacherList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(Teacher teacher)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<Teacher> teacherList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Teacher getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Teacher> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


				
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getTeacherIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countTeacherIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/TeacherService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.User;
import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Teacher;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface TeacherService extends BaseDaoService {

	



   		   
		
		public Long insert(Teacher teacher)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Teacher> insertList(List<Teacher> teacherList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(Teacher teacher)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<Teacher> teacherList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Teacher getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Teacher> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	

	public List<Long> getTeacherIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;


	public Integer countTeacherIds() throws ServiceException, ServiceDaoException;

	public void dropTeacherRelationToStundent(List<User> students, Long teacherId)throws ServiceException, ServiceDaoException;
	public void addTeacherRelationToStundent(User student, Long teacherId)throws ServiceException, ServiceDaoException;
	public void addTeacherRelationToStundents(List<User> students, Long teacherId)throws ServiceException, ServiceDaoException;


}
